@@ -1,6 +1,6 @@
 package Catmandu::Importer::getJSON;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use Catmandu::Sane;
 use Moo;
@@ -42,7 +42,7 @@ sub _trigger_url {
     }
 
     if ($url->isa('URI::Template')) {
-        unless ($url->variables) {
+        unless ( my @variables = $url->variables ) {
             $url = URI->new("$url");
         }
     }
